@@ -6,26 +6,17 @@ Use nose
 `$ nosetests test_commando.py -d -v`
 """
 
-from contextlib import nested
 from commando import *
 from mock import patch
 
 
-try:
-    import cStringIO
-    StringIO = cStringIO
-except ImportError:
-    import StringIO as xStringIO
-    StringIO = xStringIO
-
-
 def trap_exit_fail(f):
     def test_wrapper(*args):
         try:
             f(*args)
         except SystemExit:
             import traceback
-            print traceback.format_exc()
+            print (traceback.format_exc())
             assert False
     test_wrapper.__name__ = f.__name__
     return test_wrapper
@@ -34,7 +25,7 @@ def trap_exit_fail(f):
 def trap_exit_pass(f):
     def test_wrapper(*args):
         try:
-            print f.__name__
+            print (f.__name__)
             f(*args)
         except SystemExit:
             pass
@@ -186,28 +177,28 @@ class ComplexCommandLine(Application):
 
 @trap_exit_pass
 def test_command_subcommands_usage():
-    with nested(patch.object(ComplexCommandLine, '_main'),
-                patch.object(ComplexCommandLine, '_sub')) as (_main, _sub):
-        c = ComplexCommandLine()
-        c.parse(['--usage'])
+    with patch.object(ComplexCommandLine, '_main'):
+        with patch.object(ComplexCommandLine, '_sub'):
+            c = ComplexCommandLine()
+            c.parse(['--help'])
 
 
 @trap_exit_fail
 def test_command_subcommands():
-    with nested(patch.object(ComplexCommandLine, '_main'),
-                patch.object(ComplexCommandLine, '_sub')) as (_main, _sub):
-        c = ComplexCommandLine()
-        args = c.parse(['sub', '--launch', '--launch2', 'True'])
-        c.run(args)
-        assert not _main.called
-        assert _sub.call_count == 1
+    with patch.object(ComplexCommandLine, '_main') as _main:
+        with patch.object(ComplexCommandLine, '_sub') as _sub:
+            c = ComplexCommandLine()
+            args = c.parse(['sub', '--launch', '--launch2', 'True'])
+            c.run(args)
+            assert not _main.called
+            assert _sub.call_count == 1
 
 
 class EmptyCommandLine(Application):
 
     @command(description='test', prog='Empty')
     def main(self, params):
-        assert params == []
+        assert not params.__dict__
         self._main()
 
     @subcommand('sub', description='test sub')
@@ -225,22 +216,22 @@ class EmptyCommandLine(Application):
 
 @trap_exit_pass
 def test_empty_main_command():
-    with nested(patch.object(EmptyCommandLine, '_main'),
-                patch.object(EmptyCommandLine, '_sub')) as (_main, _sub):
-        e = EmptyCommandLine(raise_exceptions=True)
-        args = e.parse(None)
-        e.run(args)
-        assert not _sub.called
-        assert _main.call_count == 1
+    with patch.object(EmptyCommandLine, '_main') as _main:
+        with patch.object(EmptyCommandLine, '_sub') as _sub:
+            e = EmptyCommandLine(raise_exceptions=True)
+            args = e.parse(None)
+            e.run(args)
+            assert not _sub.called
+            assert _main.call_count == 1
 
 
 def test_empty_sub_command():
-    with nested(patch.object(EmptyCommandLine, '_main'),
-                patch.object(EmptyCommandLine, '_sub')) as (_main, _sub):
-        e = EmptyCommandLine(raise_exceptions=True)
-        e.run(e.parse(['sub']))
-        assert not _main.called
-        assert _sub.call_count == 1
+    with patch.object(EmptyCommandLine, '_main') as _main:
+        with patch.object(EmptyCommandLine, '_sub') as _sub:
+            e = EmptyCommandLine(raise_exceptions=True)
+            e.run(e.parse(['sub']))
+            assert not _main.called
+            assert _sub.call_count == 1
 
 
 class NestedCommandLine(Application):
@@ -293,11 +284,10 @@ class NestedCommandLine(Application):
 
 @trap_exit_fail
 def test_nested_command_subcommands():
-    with nested(patch.object(NestedCommandLine, '_main'),
-                patch.object(NestedCommandLine, '_sub'),
-                patch.object(NestedCommandLine, '_foobar_bla'),
-                patch.object(NestedCommandLine, '_foobar_blip_blop')) \
-                as (_main, _sub, _foobar_bla, _foobar_blip_blop):
+    with patch.object(NestedCommandLine, '_main') as _main, \
+         patch.object(NestedCommandLine, '_sub') as _sub, \
+         patch.object(NestedCommandLine, '_foobar_bla') as _foobar_bla, \
+         patch.object(NestedCommandLine, '_foobar_blip_blop') as _foobar_blip_blop:
 
         c = NestedCommandLine(raise_exceptions=True)
 
